BitfieldDatatypeWriter class

Writer for bitfield HDF5 datatypes

This class handles writing datatype messages for bitfield types, which represent bit-level data storage. Bitfields are used for packed bit flags and other bit-oriented data.

The writer follows HDF5 datatype message format version 1 for bitfield class (4).

Example usage:

// Create an 8-bit bitfield
final writer = BitfieldDatatypeWriter(
  size: 1,
);

// Create a 32-bit bitfield
final writer2 = BitfieldDatatypeWriter(
  size: 4,
);

final message = writer.writeMessage();
Inheritance

Constructors

BitfieldDatatypeWriter({required int size, Endian endian = Endian.little})
Create a writer for bitfield datatype

Properties

datatypeClass Hdf5DatatypeClass
Get the HDF5 datatype class
no setteroverride
endian Endian
Get the byte order for this datatype
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSize() int
Get the size of the datatype in bytes
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeMessage() List<int>
Write the datatype message bytes
override

Operators

operator ==(Object other) bool
The equality operator.
inherited