ConversionOptions class

Conversion options

Constructors

ConversionOptions({required DataFormat targetFormat, CompressionCodec? compression, int compressionLevel = 6, List<int>? chunkShape, bool preserveAttributes = true, bool overwrite = false})
const

Properties

chunkShape List<int>?
Chunk shape for chunked formats
final
compression CompressionCodec?
Compression codec
final
compressionLevel int
Compression level
final
hashCode int
The hash code for this object.
no setterinherited
overwrite bool
Overwrite existing file
final
preserveAttributes bool
Preserve attributes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetFormat DataFormat
Target format
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited