columnTypes property

Map<String, Type>? get columnTypes

For heterogeneous structures, get type information per column/dimension

Returns null for homogeneous structures or structures without named columns. For DataFrame, returns a map of column names to their inferred types.

Example:

var df = DataFrame({'a': [1, 2], 'b': ['x', 'y']});
print(df.columnTypes);  // {'a': int, 'b': String}

var array = NDArray([1, 2, 3]);
print(array.columnTypes);  // null

Implementation

Map<String, Type>? get columnTypes => null;