LazyOperation class abstract

Lazy operation that defers computation until needed.

Base class for lazy evaluation operations. Computations are deferred until materialization or element access.

This enables:

  • Operation fusion for better performance
  • Memory efficiency for large arrays
  • Pipeline optimization
Implementers

Constructors

LazyOperation()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape Shape
Shape of the result
no setter

Methods

compute(List<int> indices) → dynamic
Compute value at specific indices
materialize() NDArray
Materialize the entire operation into an NDArray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() LazyOperation
Optimize the operation (e.g., fusion)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited