LocalHeap class

Local heap for storing variable-length data

Properties

address int
final
dataSegmentAddress int
final
dataSegmentSize int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData(int offset, int length) Future<Uint8List>
Read data from the heap at the given offset
readString(int offset) Future<String>
Read a null-terminated string from the heap at the given offset
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

read(ByteReader reader, int address, {String? filePath}) Future<LocalHeap>
Read a local heap from the file