NotADatasetError class
Error thrown when an object is not a dataset
Constructors
- NotADatasetError({String? filePath, required String objectPath, String? actualType})
Properties
- details → String?
-
finalinherited
- filePath → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- objectPath → String?
-
finalinherited
- operation → String
-
finalinherited
- originalError → Object?
-
finalinherited
-
recoverySuggestions
→ List<
String> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited