DCFHeader class
DCF File Layout:
[Header - 512 bytes]
- Magic: "DCF\0" (4 bytes)
- Version: uint16 (2 bytes)
- Flags: uint32 (4 bytes)
- Root offset: uint64 (8 bytes)
- Metadata offset: uint64 (8 bytes)
- Index offset: uint64 (8 bytes)
- Data offset: uint64 (8 bytes)
- File size: uint64 (8 bytes)
- Checksum: uint32 (4 bytes)
- Reserved: (462 bytes)
[Metadata Section]
- JSON metadata
- Schema definitions
- Compression info
- Custom attributes
[Group Tree]
- Hierarchical structure
- Group metadata
- Dataset references
[Dataset Index]
- Dataset metadata
- Chunk offset table
- Chunk size table
- Compression info per chunk
[Data Chunks]
- Compressed/uncompressed chunks
- Independent compression per chunk
- Aligned for fast access
DCF File Header
Constructors
-
DCFHeader({required List<
int> magic, required int version, required int flags, required int rootOffset, required int metadataOffset, required int indexOffset, required int dataOffset, required int fileSize, required int checksum}) - DCFHeader.create()
-
Create default header
factory
-
DCFHeader.fromBytes(List<
int> bytes) -
Deserialize header from bytes
factory
Properties
- checksum → int
-
Header checksum (CRC32)
final
- dataOffset → int
-
Offset to data section
final
- fileSize → int
-
Total file size
final
- flags → int
-
File flags
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexOffset → int
-
Offset to dataset index
final
-
magic
→ List<
int> -
Magic number
final
- metadataOffset → int
-
Offset to metadata section
final
- rootOffset → int
-
Offset to root group
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
Format version
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> - Serialize header to bytes
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → bool - Validate header
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited