DataReader class abstract
Abstract base class for data readers.
This interface defines the contract that all file format readers must implement. Each reader is responsible for reading a specific file format and converting it to a DataFrame.
Implementations include:
- CsvReader for CSV files
- ExcelFileReader for Excel files
- HDF5Reader for HDF5 files
- MATReader for MATLAB .mat files (v7.3 only)
ParquetReaderfor Parquet files (basic implementation)
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String path, {Map< String, dynamic> ? options}) → Future<DataFrame> - Reads data from the specified path and returns a DataFrame.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited