Int64DType class
Properties
-
dartType
→ Type
-
Dart type that this DType represents.
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
itemSize
→ int
-
Size in bytes (null for variable-size types).
no setteroverride
-
name
→ String
-
Name of the data type.
no setteroverride
-
nullable
→ bool
-
Whether this type is nullable.
no setteroverride
-
nullValue
→ dynamic
-
Get the null/missing value for this type.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(dynamic value)
→ dynamic
-
Convert a value to this type.
override
-
isNull(dynamic value)
→ bool
-
Check if a value is null/missing.
override
-
isValid(dynamic value)
→ bool
-
Check if a value is valid for this type.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
String representation.
inherited